@@ -7,11 +7,12 @@
 
 namespace aria2 {
 
-class DHTTaskExecutorTest:public CppUnit::TestFixture {
+class DHTTaskExecutorTest : public CppUnit::TestFixture {
 
   CPPUNIT_TEST_SUITE(DHTTaskExecutorTest);
   CPPUNIT_TEST(testUpdate);
   CPPUNIT_TEST_SUITE_END();
+
 public:
   void testUpdate();
 };
@@ -20,16 +21,15 @@ CPPUNIT_TEST_SUITE_REGISTRATION(DHTTaskExecutorTest);
 
 void DHTTaskExecutorTest::testUpdate()
 {
-  SharedHandle<DHTNode> rn;
+  std::shared_ptr<DHTNode> rn;
   DHTTaskExecutor tex(2);
-  SharedHandle<MockDHTTask> tasks[] = {
-    SharedHandle<MockDHTTask>(new MockDHTTask(rn)),
-    SharedHandle<MockDHTTask>(new MockDHTTask(rn)),
-    SharedHandle<MockDHTTask>(new MockDHTTask(rn)),
-    SharedHandle<MockDHTTask>(new MockDHTTask(rn))
-  };
+  std::shared_ptr<MockDHTTask> tasks[] = {
+      std::shared_ptr<MockDHTTask>(new MockDHTTask(rn)),
+      std::shared_ptr<MockDHTTask>(new MockDHTTask(rn)),
+      std::shared_ptr<MockDHTTask>(new MockDHTTask(rn)),
+      std::shared_ptr<MockDHTTask>(new MockDHTTask(rn))};
   tasks[1]->finished_ = true;
-  for(size_t i = 0; i < A2_ARRAY_LEN(tasks); ++i) {
+  for (size_t i = 0; i < arraySize(tasks); ++i) {
     tex.addTask(tasks[i]);
   }
   CPPUNIT_ASSERT_EQUAL((size_t)0, tex.getExecutingTaskSize());
